@@ -15,9 +15,8 @@ sgp30 = adafruit_sgp30.Adafruit_SGP30(i2c)
 
 print("SGP30 serial #", [hex(i) for i in sgp30.serial])
 
-sgp30.iaq_init()
 sgp30.set_iaq_baseline(0x8973, 0x8AAE)
-sgp30.set_iaq_relative_humidity(celcius=22.1, relative_humidity=44)
+sgp30.set_iaq_relative_humidity(celsius=22.1, relative_humidity=44)
 
 elapsed_sec = 0
 
